package com.caimei.service.auth;

import com.caimei.model.ResponseJson;
import com.caimei.model.po.CmBrandAuthPo;
import com.caimei.model.vo.AuthFormVo;
import com.caimei.model.vo.AuthVo;
import com.caimei.model.vo.ProductFormVo;
import com.caimei.model.vo.TemplateVo;
import com.github.pagehelper.PageInfo;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface AuthService {

    /**
     * 授权列表
     *
     * @param listType         列表类型：1授权列表，2授权审核列表
     * @param authUserId       供应商用户id
     * @param authParty        授权机构
     * @param mobile
     * @param status           上线状态：0已下线，1已上线，2待上线
     * @param starFlag         明星机构标识：0不是，1是
     * @param lowerAuditStatus 商品信息审核状态:0未完成审核，1已完成审核
     * @param shopAuditStatus  供应商审核状态:0审核未通过，1审核通过，2待审核
     * @param pageNum          第几页
     * @param pageSize         一页多少条
     * @param auditStatus      审核状态:0审核未通过，1审核通过，2待审核
     * @return AuthVo
     */
    ResponseJson<PageInfo<AuthVo>> getAuthList(Integer listType, Integer authUserId, String authParty, String mobile, Integer status, Integer starFlag, Integer auditStatus, Integer lowerAuditStatus, Integer shopAuditStatus, Integer sendStatus,String authCode ,Integer pageNum, Integer pageSize);
    ResponseJson<PageInfo<AuthVo>> getAuthListAll(Integer listType, Integer authUserId, String authParty, String mobile, Integer status, Integer starFlag, Integer auditStatus, Integer lowerAuditStatus, Integer shopAuditStatus, Integer sendStatus, String name,String snCode,Integer pageNum, Integer pageSize);

    /**
     * 更新授权状态
     *
     * @param authId 授权id
     * @param status 授权状态:0停用 1启用
     * @return ResponseJson
     */
    ResponseJson updateAuthStatus(Integer authId, Integer status);

    /**
     * 删除授权
     * @param authId    授权id
     * @return  ResponseJson
     */
    ResponseJson deleteAuth(Integer authId);

    /**
     * 添加/编辑授权
     *
     * @param auth       授权机构
     * @param bannerList 轮播图列表
     * @param source     来源：1供应商保存，2机构保存
     * @return ResponseJson
     */
    ResponseJson saveAuth(CmBrandAuthPo auth, List<String> bannerList, boolean importFlag, Integer source);

    /**
     * 审核品牌授权
     *
     * @param authId            授权id
     * @param auditStatus       审核状态
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @param source
     * @return ResponseJson
     */
    ResponseJson auditAuth(Integer authId, Integer auditStatus, String invalidReason, Integer auditBy, Integer source);

    /**
     * 导入excel中的授权机构和商品数据
     * @param file          excel表格
     * @param authUserId    供应商用户id
     * @param createBy
     * @return
     */
    ResponseJson importDataByExcel(MultipartFile file, Integer authUserId, Integer createBy);

    /**
     * 授权机构回显数据
     * @param authId    机构id
     * @return
     */
    ResponseJson<AuthFormVo> getAuthFormData(Integer authId);

    /**
     * 机构下拉框列表
     */
    ResponseJson<List<AuthVo>> getAuthSelectList(Integer authUserId);

    /**
     * ldm门店图/备注导入
     * @param authUserId
     * @return
     */
    ResponseJson importLdmImage(Integer authUserId);

    /**
     * 生成机构授权牌
     * @param auth
     * @return
     */
    String generateAuthImage(TemplateVo authTemplate, CmBrandAuthPo auth);

    /**
     * 添加水印
     */
    String addWaterMark(String image,Integer type);

    /**
     * 更改查看标记
     * @param authId
     * @return
     */
    ResponseJson checkAuth(Integer authId);

    /**
     * 更改明星标识
     */
    ResponseJson starAuth(Integer authId, Integer starFlag,String starNum);
    /**
     * 获取机构关联的机构信息
     * 1.7.4版本：编辑时新加关联机构操作
     *
     */
    ResponseJson<List<AuthFormVo>> getRelationgInfo(String  snCode, Integer authUserId);
    /**
     * 获取可绑定机构机构信息
     * **/
    ResponseJson<List<AuthFormVo>> getClubBindAuth(Integer authUserId);

    /**
     * 用户扫码授权，获取code值
     * @param response
     * @return
     * @throws IOException
     */
    ResponseJson getDouYingCode(HttpServletResponse response) throws IOException;
    /**
     * 根据用户的code值获取AcessToken
     * ccode 用户授权登录code
     **/
    ResponseJson getDouYingAcessToken(String ccode) throws IOException;
    /**
     * h5的方式上传视频
     * @return
     * @throws IOException
     */
    ResponseJson getclientToken(String title,String videoPath) throws IOException;
}
